@@ -193,16 +193,23 @@ class gui:
                 for ext in ['*.png', '*.tif', '*.jpeg', '*.tiff', '*.TIF', '*.jpg']:
                     self.valid_image_files.extend(glob.glob(os.path.join(self.base_folder, ext)))
 
+                self.valid_image_files = [*set(self.valid_image_files)]
                 self.valid_image_files.sort()
 
-                self.current_image_index = -1
-                for f in self.valid_image_files:
-                    self.current_image_index += 1
-                    if f == values['Browse']:
+                # self.current_image_index = -1
+                # for f in self.valid_image_files:
+                #     self.current_image_index += 1
+                #     if f == values['Browse']:
+                #         break
+
+                for i, f in enumerate(self.valid_image_files):
+                    if os.path.split(f) == os.path.split(values['Browse']):
+                        self.current_image_index = i
                         break
 
-                assert self.valid_image_files[self.current_image_index] == values['Browse'], f'{self.current_image_index}, {self.valid_image_files}'
 
+                if self.valid_image_files[self.current_image_index] != values['Browse']:
+                    print(f'{self.current_image_index}, {self.valid_image_files}')
 
                 self.load_image(self.valid_image_files[self.current_image_index])
 
@@ -433,10 +440,11 @@ class gui:
         self.window.refresh()
 
     def draw_figure(self):
-        figure_canvas_agg = FigureCanvasTkAgg(self.fig, self.window['Histogram'].TKCanvas)
-        figure_canvas_agg.draw()
-        figure_canvas_agg.get_tk_widget().pack(side='top', fill='both', expand=1)
-        self.fig_agg = figure_canvas_agg
+        pass
+        # figure_canvas_agg = FigureCanvasTkAgg(self.fig, self.window['Histogram'].TKCanvas)
+        # figure_canvas_agg.draw()
+        # figure_canvas_agg.get_tk_widget().pack(side='top', fill='both', expand=1)
+        # self.fig_agg = figure_canvas_agg
 
     def draw_image(self):
         cell_key = {'OHC': '#56B4E9', 'IHC': '#E69F00'}
